@@ -222,23 +222,38 @@ def create_keyring_template(keyring_loc: Path, args: object) -> None:
         for study in args.studies:
             template_dict['lochness']['SECRETS'][study] = 'LOCHNESS_SECRETS'
 
+            if args.enter_passwords:
+                mediaflux_user = getpass.getpass('Mediaflux User: ')
+                mediaflux_password = getpass.getpass('Mediaflux Password: ')
+            else:
+                mediaflux_user = '*****'
+                mediaflux_password = '*****'
+
             # lower part of the keyring
             template_dict[f'mediaflux.{study}'] = {
                 'HOST': 'mediaflux.researchsoftware.unimelb.edu.au',
                 'PORT': '443',
                 'TRANSPORT': 'https',
-                'TOKEN': '**TOKEN_delete_this_line_if_no_token**',
                 'DOMAIN': 'local',
-                'USER': '**ID**',
-                'PASSWORD': '**PASSWORD**'}
+                'USER': mediaflux_user,
+                'PASSWORD': mediaflux_password}
 
     if 'mindlamp' in args.sources:
         for study in args.studies:
             # lower part of the keyring
+            if args.enter_passwords:
+                mindlamp_url = getpass.getpass('Mindlamp URL: ')
+                mindlamp_ak = getpass.getpass('Mindlamp Access key: ')
+                mindlamp_sk = getpass.getpass('Mindlamp  Secret key: ')
+            else:
+                mindlamp_url = '*****'
+                mindlamp_ak = '*****'
+                mindlamp_sk = '*****'
+
             template_dict[f'mindlamp.{study}'] = {
-                "URL": "**api.lamp.digital**",
-                "ACCESS_KEY": args.email,
-                "SECRET_KEY": "**PASSWORD**"}
+                "URL": mindlamp_url,
+                "ACCESS_KEY": mindlamp_ak,
+                "SECRET_KEY": mindlamp_sk}
 
     if 'daris' in args.sources:
         for study in args.studies:
@@ -305,6 +320,11 @@ lochness_sync_history_csv: {args.lochness_sync_history_csv}
 RPMS_id_colname: subjectkey
 RPMS_consent_colname: Consent
 '''
+    if 'redcap' in args.sources:
+        config_example += '''redcap_id_colname: chric_record_id
+redcap_consent_colname: chric_consent_date
+'''
+
 
     if args.s3:
         if 'rpms' in args.sources:
@@ -343,23 +363,14 @@ AWS_BUCKET_ROOT: TEST_PHOENIX_ROOT_PRONET'''
         delete_on_success: False
         file_patterns:
             actigraphy:
-                - vendor: Philips
-                  product: Actiwatch 2
-                  data_dir: Actigraphy
-                  pattern: '*csv'
-                  protect: True
-                - vendor: Activinsights
-                  product: GENEActiv
-                  data_dir: Actigraphy
-                  pattern: '*csv'
                 - vendor: Insights
                   product: GENEActivQC
                   data_dir: Actigraphy
-                  pattern: '*csv'
+                  pattern: '*.(cwa|csv)'
             eeg:
                    - product: eeg
                      data_dir: EEG
-                     pattern: '*.csv'
+                     pattern: '*.(csv|zip)'
             interviews:
                    - product: offsite_interview
                      data_dir: Interview_recordings
@@ -373,7 +384,7 @@ AWS_BUCKET_ROOT: TEST_PHOENIX_ROOT_PRONET'''
         for study in args.studies:
             line_to_add = f'''
     {study}:
-        base: /example_box_root/{study}
+        base: ProNET/{study}
         delete_on_success: False
         file_patterns:
             actigraphy:
